@@ -28,7 +28,7 @@ from .common import (  # noqa: F401
     ResponseError, PaymentException,
 )
 
-__all__ = ['Payment', 'URL', 'HTML', 'FORM', 'SIPS', 'SYSTEMPAY', 'SPPLUS',
+__all__ = ['Payment', 'URL', 'HTML', 'FORM', 'SIPS', 'SYSTEMPAY',
            'TIPI', 'DUMMY', 'get_backend', 'RECEIVED', 'ACCEPTED', 'PAID',
            'DENIED', 'CANCELED', 'CANCELLED', 'ERROR', 'WAITING',
            'get_backends', 'PAYFIP_WS']
@@ -39,7 +39,6 @@ if six.PY3:
 SIPS = 'sips'
 SIPS2 = 'sips2'
 SYSTEMPAY = 'systempayv2'
-SPPLUS = 'spplus'
 TIPI = 'tipi'
 DUMMY = 'dummy'
 OGONE = 'ogone'
@@ -57,7 +56,7 @@ def get_backend(kind):
     module = importlib.import_module('.' + kind, package='eopayment')
     return module.Payment
 
-__BACKENDS = [DUMMY, SIPS, SIPS2, SYSTEMPAY, SPPLUS, OGONE, PAYBOX, PAYZEN,
+__BACKENDS = [DUMMY, SIPS, SIPS2, SYSTEMPAY, OGONE, PAYBOX, PAYZEN,
               TIPI, PAYFIP_WS, KEYWARE, MOLLIE]
 
 
@@ -77,23 +76,25 @@ class Payment(object):
        Interface to credit card online payment servers of French banks. The
        only use case supported for now is a unique automatic payment.
 
-           >>> spplus_options = { \
-                   'cle': '58 6d fc 9c 34 91 9b 86 3f fd 64 ' \
-                          '63 c9 13 4a 26 ba 29 74 1e c7 e9 80 79', \
-                   'siret': '00000000000001-01', \
+           >>> options = {
+                   'numcli': '12345',
                }
-           >>> p = Payment(kind=SPPLUS, options=spplus_options)
+           >>> p = Payment(kind=TIPI, options=options)
            >>> transaction_id, kind, data = p.request('10.00', email='bob@example.com')
            >>> print (transaction_id, kind, data) # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
-           ('...', 1, 'https://www.spplus.net/paiement/init.do?...')
+           ('...', 1, 'https://www.payfip.gov.fr/tpa/paiement.web?...')
 
        Supported backend of French banks are:
 
-        - sips, for BNP, Banque Populaire (before 2010), CCF, HSBC, Crédit
+        - TIPI/PayFiP
+        - SIPS 2.0, for BNP, Banque Populaire (before 2010), CCF, HSBC, Crédit
           Agricole, La Banque Postale, LCL, Société Générale and Crédit du
           Nord.
-        - spplus for Caisse d'épargne
-        - systempay for Banque Populaire (after 2010)
+        - SystemPay v2/Payzen for Banque Populaire and Caise d'Epargne (Natixis, after 2010)
+        - Ogone
+        - Paybox
+        - Mollie (Belgium)
+        - Keyware (Belgium)
 
        For SIPs you also need the bank provided middleware especially the two
        executables, request and response, as the protocol from ATOS/SIPS is not
