@@ -20,7 +20,8 @@ import requests
 from six.moves.urllib.parse import parse_qs, urljoin
 
 from .common import (CANCELLED, ERROR, PAID, URL, PaymentCommon,
-                     PaymentException, PaymentResponse, ResponseError)
+                     PaymentException, PaymentResponse, ResponseError, WAITING,
+                     ACCEPTED)
 
 __all__ = ['Payment']
 
@@ -103,6 +104,10 @@ class Payment(PaymentCommon):
             result = PAID
         elif status in ('canceled', 'expired'):
             result = CANCELLED
+        elif status in ('open', 'pending'):
+            result = WAITING
+        elif status == 'authorized':
+            result = ACCEPTED
         else:
             result = ERROR
 
