@@ -22,6 +22,7 @@ import logging
 import hashlib
 import hmac
 import requests
+import uuid
 
 import pytz
 
@@ -284,6 +285,15 @@ class Payment(PaymentCommon):
         ]
     }
 
+    def make_pbx_cmd(self, guid, orderid=None, transaction_id=None):
+        if not transaction_id:
+            date = datetime.datetime.now(pytz.timezone(self.timezone)).strftime('%Y-%m-%dT%H%M%S')
+            transaction_id = '%s_%s' % (date, guid)
+        pbx_cmd = transaction_id
+        if orderid:
+            pbx_cmd += '!' + orderid
+        return pbx_cmd
+
     def request(self, amount, email, name=None, orderid=None, manual_validation=None, **kwargs):
         d = OrderedDict()
         d['PBX_SITE'] = force_text(self.site)
@@ -291,13 +301,10 @@ class Payment(PaymentCommon):
         d['PBX_IDENTIFIANT'] = force_text(self.identifiant)
         d['PBX_TOTAL'] = self.clean_amount(amount)
         d['PBX_DEVISE'] = force_text(self.devise)
-        transaction_id = kwargs.get('transaction_id') or \
-            self.transaction_id(12, string.digits, 'paybox', self.site,
-                                self.rang, self.identifiant)
-        d['PBX_CMD'] = force_text(transaction_id)
-        # prepend order id command reference
-        if orderid:
-            d['PBX_CMD'] = orderid + ORDERID_TRANSACTION_SEPARATOR + d['PBX_CMD']
+        guid = str(uuid.uuid4().hex)
+        transaction_id = d['PBX_CMD'] = self.make_pbx_cmd(guid=guid,
+                                                          transaction_id=kwargs.get('transaction_id'),
+                                                          orderid=orderid)
         d['PBX_PORTEUR'] = force_text(email)
         d['PBX_RETOUR'] = (
             'montant:M;reference:R;code_autorisation:A;erreur:E;numero_appel:T;'
@@ -309,7 +316,7 @@ class Payment(PaymentCommon):
         d['PBX_TIME'] = kwargs.get('time') or (
             force_text(datetime.datetime.utcnow().isoformat('T')).split('.')[0]
             + '+00:00')
-        d['PBX_ARCHIVAGE'] = transaction_id
+        d['PBX_ARCHIVAGE'] = orderid or guid
         if self.normal_return_url:
             d['PBX_EFFECTUE'] = self.normal_return_url
             d['PBX_REFUSE'] = self.normal_return_url
@@ -378,10 +385,7 @@ class Payment(PaymentCommon):
             bank_status = PAYBOX_ERROR_CODES.get(prefix + suffix)
             if bank_status is not None:
                 break
-        orderid = d['reference'][0]
-        # decode order id from returned reference
-        if ORDERID_TRANSACTION_SEPARATOR in orderid:
-            orderid, transaction_id = orderid.split(ORDERID_TRANSACTION_SEPARATOR, 1)
+        pbx_cmd = d['reference'][0]
         transaction_date = None
         if 'date_transaction' in d and 'heure_transaction' in d:
             try:
@@ -395,7 +399,7 @@ class Payment(PaymentCommon):
                 paris_tz = pytz.timezone(self.timezone)
                 transaction_date = paris_tz.localize(transaction_date)
         return PaymentResponse(
-            order_id=orderid,
+            order_id=pbx_cmd,
             signed=signed,
             bank_data=d,
             result=result,
