@@ -20,14 +20,17 @@ import pytz
 import datetime as dt
 import hashlib
 import hmac
+import random
+import re
 import string
+import six
 from six.moves.urllib import parse as urlparse
 import warnings
 from gettext import gettext as _
 
-from .common import (PaymentCommon, PaymentResponse, PAID, ERROR, FORM, Form,
-                     ResponseError, force_text, force_byte)
-from .cb import CB_RESPONSE_CODES
+from .common import (PaymentCommon, PaymentResponse, PAID, DENIED, CANCELLED,
+                     ERROR, FORM, Form, ResponseError, force_text, force_byte)
+from .cb import translate_cb_error_code
 
 __all__ = ['Payment']
 
@@ -156,7 +159,8 @@ PARAMETERS = [
     Parameter('vads_theme_config', 'ans', 32, max_length=255),
     Parameter(VADS_TRANS_DATE, 'n', 4, length=14, needed=True,
               default=isonow),
-    Parameter('vads_trans_id', 'n', 3, length=6, needed=True),
+    # https://paiement.systempay.fr/doc/fr-FR/form-payment/reference/vads-trans-id.html
+    Parameter('vads_trans_id', 'an', 3, length=6, needed=True),
     Parameter('vads_validation_mode', 'n', 5, max_length=1, choices=('', '0', '1'),
               default=''),
     Parameter('vads_version', 'an', 1, default='V2', needed=True,
@@ -175,31 +179,6 @@ PARAMETERS = [
 PARAMETER_MAP = dict(((parameter.name,
                        parameter) for parameter in PARAMETERS))
 
-AUTH_RESULT_MAP = CB_RESPONSE_CODES
-
-RESULT_MAP = {
-    '00': 'paiement réalisé avec succés',
-    '02': 'le commerçant doit contacter la banque du porteur',
-    '05': 'paiement refusé',
-    '17': 'annulation client',
-    '30': 'erreur de format',
-    '96': 'erreur technique lors du paiement'
-}
-
-EXTRA_RESULT_MAP = {
-    '': "Pas de contrôle effectué",
-    '00': "Tous les contrôles se sont déroulés avec succés",
-    '02': "La carte a dépassé l'encours autorisé",
-    '03': "La carte appartient à la liste grise du commerçant",
-    '04': "Le pays d'émission de la carte appartient à la liste grise du "
-    "commerçant ou le pays d'émission de la carte n'appartient pas à la "
-    "liste blanche du commerçant",
-    '05': "L'addresse IP appartient à la liste grise du commerçant",
-    '99': "Problème technique recontré par le serveur lors du traitement "
-    "d'un des contrôles locaux",
-}
-
-
 def add_vads(kwargs):
     new_vargs = {}
     for k, v in kwargs.items():
@@ -314,6 +293,21 @@ class Payment(PaymentCommon):
         options = add_vads(options)
         self.options = options
 
+    def make_vads_trans_id(self):
+        # vads_trans_id must be 6 alphanumeric characters,
+        # trans_id starting with 9 are reserved for the systempay backoffice
+        # https://paiement.systempay.fr/doc/fr-FR/form-payment/reference/vads-trans-id.html
+        gen = random.SystemRandom()
+        if six.PY3:
+            alphabet = string.ascii_letters + string.digits
+        else:
+            alphabet = string.letters + string.digits
+        first_letter_alphabet = alphabet.replace('9', '')
+        vads_trans_id = (
+            gen.choice(first_letter_alphabet)
+            + ''.join(gen.choice(alphabet) for i in range(5))
+        )
+        return vads_trans_id
 
     def request(self, amount, name=None, first_name=None, last_name=None,
                 address=None, email=None, phone=None, orderid=None, info1=None,
@@ -368,9 +362,10 @@ class Payment(PaymentCommon):
                     '%s value %s is not of the type %s' % (name, orderid, ptype))
             kwargs[name] = orderid
 
-        transaction_id = self.transaction_id(6, string.digits, 'systempay',
-                                             self.options[VADS_SITE_ID])
-        kwargs[VADS_TRANS_ID] = force_text(transaction_id)
+        vads_trans_id = self.make_vads_trans_id()
+        assert re.match(r'^[0-9a-zA-Z]{6}$', vads_trans_id)
+
+        kwargs[VADS_TRANS_ID] = vads_trans_id
         fields = kwargs
         for parameter in PARAMETERS:
             name = parameter.name
@@ -392,7 +387,7 @@ class Payment(PaymentCommon):
         check_vads(fields)
         fields[SIGNATURE] = force_text(self.signature(fields))
         self.logger.debug('%s request contains fields: %s', __name__, fields)
-        transaction_id = '%s_%s' % (fields[VADS_TRANS_DATE], transaction_id)
+        transaction_id = '%s_%s' % (fields[VADS_TRANS_DATE], vads_trans_id)
         self.logger.debug('%s transaction id: %s', __name__, transaction_id)
         form = Form(
             url=self.service_url,
@@ -406,6 +401,72 @@ class Payment(PaymentCommon):
                 for field_name, field_value in fields.items()])
         return transaction_id, FORM, form
 
+    RESULT_MAP = {
+        '00': {'message': 'Paiement réalisé avec succés.', 'result': PAID},
+        '02': {'message': 'Le commerçant doit contacter la banque du porteur.'},
+        '05': {'message': 'Paiement refusé.', 'result': DENIED},
+        '17': {'message': 'Annulation client.', 'result': CANCELLED},
+        '30': {'message': 'Erreur de format.'},
+        '96': {'message': 'Erreur technique lors du paiement.'},
+    }
+
+    EXTRA_RESULT_MAP = {
+        '': {'message': 'Pas de contrôle effectué.'},
+        '00': {'message': 'Tous les contrôles se sont déroulés avec succés.'},
+        '02': {'message': 'La carte a dépassé l\'encours autorisé.'},
+        '03': {'message': 'La carte appartient à la liste grise du commerçant.'},
+        '04': {'messaǵe': 'Le pays d\'émission de la carte appartient à la liste grise du '
+               'commerçant ou le pays d\'émission de la carte n\'appartient pas à la '
+               'liste blanche du commerçant.'},
+        '05': {'message': 'L’adresse IP appartient à la liste grise du marchand.'},
+        '06': {'message': 'Le code bin appartient à la liste grise du marchand.'},
+        '07': {'message': 'Détection d’une e-carte bleue.'},
+        '08': {'message': 'Détection d’une carte commerciale nationale.'},
+        '09': {'message': 'Détection d’une carte commerciale étrangère.'},
+        '14': {'message': 'Détection d’une carte à autorisation systématique.'},
+        '30': {'message': 'Le pays de l’adresse IP appartient à la liste grise.'},
+        '99': {'message': 'Problème technique recontré par le serveur lors du traitement '
+               'd\'un des contrôles locauxi.'},
+    }
+
+    @classmethod
+    def make_eopayment_result(cls, fields):
+        # https://paiement.systempay.fr/doc/fr-FR/payment-file/oneclick-payment/vads-result.html
+        # https://paiement.systempay.fr/doc/fr-FR/payment-file/oneclick-payment/vads-auth-result.html
+        # https://paiement.systempay.fr/doc/fr-FR/payment-file/oneclick-payment/vads-extra-result.html
+        vads_result = fields.get(VADS_RESULT)
+        vads_auth_result = fields.get(VADS_AUTH_RESULT)
+        vads_extra_result = fields.get(VADS_EXTRA_RESULT)
+
+        # map to human messages and update return
+        vads_result_message = cls.RESULT_MAP.get(vads_result, {}).get('message')
+        if vads_result_message:
+            fields[VADS_RESULT + '_message'] = vads_result_message
+
+        vads_extra_result_message = cls.EXTRA_RESULT_MAP.get(vads_extra_result, {}).get('message')
+        if vads_extra_result_message:
+            fields[VADS_EXTRA_RESULT + '_message'] = vads_extra_result_message
+
+        vads_auth_result_message, auth_eopayment_result = translate_cb_error_code(vads_auth_result)
+        if vads_auth_result_message:
+            fields[VADS_AUTH_RESULT + '_message'] = vads_auth_result_message
+
+        # now build eopayment resume
+        if vads_result is None:
+            return ERROR, 'absence de champ vads_result'
+        if vads_result_message is None:
+            return ERROR, 'valeur vads_result inconnue'
+
+        result = cls.RESULT_MAP[vads_result].get('result', ERROR)
+        message = vads_result_message
+        if vads_auth_result_message and (vads_result != '00' or vads_result != vads_auth_result):
+            message += ' ' + vads_auth_result_message
+        if vads_result in ('00', '05', '30') and vads_extra_result_message and vads_extra_result != '':
+            message += ' ' + vads_extra_result_message
+        if result == ERROR and auth_eopayment_result not in (PAID, ERROR, None):
+            result = auth_eopayment_result
+        return result, message
+
     def response(self, query_string, **kwargs):
         fields = urlparse.parse_qs(query_string, True)
         if not set(fields) >= set([SIGNATURE, VADS_CTX_MODE, VADS_AUTH_RESULT]):
@@ -414,46 +475,17 @@ class Payment(PaymentCommon):
         for key, value in fields.items():
             fields[key] = value[0]
         copy = fields.copy()
-        bank_status = []
-        if VADS_AUTH_RESULT in fields:
-            v = copy[VADS_AUTH_RESULT]
-            ctx = (v, AUTH_RESULT_MAP.get(v, 'Code inconnu'))
-            copy[VADS_AUTH_RESULT] = '%s: %s' % ctx
-            bank_status.append(copy[VADS_AUTH_RESULT])
-        if VADS_RESULT in copy:
-            v = copy[VADS_RESULT]
-            ctx = (v, RESULT_MAP.get(v, 'Code inconnu'))
-            copy[VADS_RESULT] = '%s: %s' % ctx
-            bank_status.append(copy[VADS_RESULT])
-            if v == '30':
-                if VADS_EXTRA_RESULT in fields:
-                    v = fields[VADS_EXTRA_RESULT]
-                    if v.isdigit():
-                        for parameter in PARAMETERS:
-                            if int(v) == parameter.code:
-                                s = 'erreur dans le champ %s' % parameter.name
-                                copy[VADS_EXTRA_RESULT] = s
-                                bank_status.append(copy[VADS_EXTRA_RESULT])
-            elif v in ('05', '00'):
-                if VADS_EXTRA_RESULT in fields:
-                    v = fields[VADS_EXTRA_RESULT]
-                    extra_result_name = EXTRA_RESULT_MAP.get(v, 'Code inconnu')
-                    copy[VADS_EXTRA_RESULT] = '%s: %s' % (v, extra_result_name)
-                    bank_status.append(copy[VADS_EXTRA_RESULT])
-        self.logger.debug('checking systempay response on:')
-        for key in sorted(fields.keys()):
-            self.logger.debug('  %s: %s' % (key, copy[key]))
         signature = self.signature(fields)
+        result, message = self.make_eopayment_result(copy)
+        self.logger.debug('checking systempay response on: %r', copy)
         signature_result = signature == fields[SIGNATURE]
-        self.logger.debug('signature check: %s <!> %s', signature,
-                          fields[SIGNATURE])
         if not signature_result:
-            bank_status.append('invalid signature')
+            self.logger.debug('signature check: %s <!> %s', signature,
+                              fields[SIGNATURE])
+
+        if not signature_result:
+            message += ' signature invalide.'
 
-        if fields[VADS_AUTH_RESULT] == '00':
-            result = PAID
-        else:
-            result = ERROR
         test = fields[VADS_CTX_MODE] == 'TEST'
         transaction_id = '%s_%s' % (copy[VADS_TRANS_DATE], copy[VADS_TRANS_ID])
         # the VADS_AUTH_NUMBER is the number to match payment in bank logs
@@ -467,7 +499,7 @@ class Payment(PaymentCommon):
             bank_data=copy,
             order_id=transaction_id,
             transaction_id=copy.get(VADS_AUTH_NUMBER),
-            bank_status=' - '.join(bank_status),
+            bank_status=message,
             transaction_date=transaction_date,
             test=test)
         return response
