@@ -24,7 +24,7 @@ import pytest
 @pytest.fixture
 def backend():
     options = {
-        'direct_notification_url': 'http://example.com/direct_notification_url',
+        'automatic_notification_url': 'http://example.com/direct_notification_url',
         'siret': '1234',
         'origin': 'Mairie de Perpette-les-oies'
     }
