@@ -87,7 +87,7 @@ class PayboxTests(TestCase):
             Decimal(amount), email=email, orderid=order_id,
             transaction_id=transaction, time=time, manual_validation=False)
         self.assertEqual(kind, eopayment.FORM)
-        self.assertEqual(transaction_id, '1234')
+        self.assertEqual(transaction_id, '%s!%s' % (transaction, order_id))
         root = ET.fromstring(str(what))
         self.assertEqual(root.tag, 'form')
         self.assertEqual(root.attrib['method'], 'POST')
@@ -103,17 +103,16 @@ class PayboxTests(TestCase):
             ),
             'PBX_TIME': time,
             'PBX_PORTEUR': email,
-            'PBX_CMD': order_id + eopayment.common.ORDERID_TRANSACTION_SEPARATOR + transaction,
+            'PBX_CMD': '%s!%s' % (transaction, order_id),
             'PBX_TOTAL': amount.replace('.', ''),
             'PBX_DEVISE': '978',
             'PBX_HASH': 'SHA512',
             'PBX_HMAC': (
-                'CE29AB421D9FF5E22B52A0F0D31BB881E6D'
-                '3040B7A0B390AC3F335292A75D2389253A3'
-                'ED6B3E430A90D30088F6AC29F792B484A2E'
-                'CFC36A1B73771796A5FD15C'
+                '300CFBDFF0454403BE7FEA11B9714C6B134294313E'
+                '7A052580F517BFCB117FB6A175C2E0DC81F6137D95'
+                '8FCA3CC4F8F1883A479C474C3A7B871CCA2DB8D033D9'
             ),
-            'PBX_ARCHIVAGE': '1234',
+            'PBX_ARCHIVAGE': '20160216',
             'PBX_REPONDRE_A': 'http://example.com/callback',
             'PBX_AUTOSEULE': 'N'
         }
@@ -203,7 +202,7 @@ class PayboxTests(TestCase):
         backend = eopayment.Payment('paybox', BACKEND_PARAMS)
         order_id = '20160216'
         transaction = '1234'
-        reference = order_id + eopayment.common.ORDERID_TRANSACTION_SEPARATOR + transaction
+        reference = '%s!%s' % (transaction, order_id)
         data = {
             'montant': '4242',
             'reference': reference,
@@ -212,7 +211,7 @@ class PayboxTests(TestCase):
             'date_transaction': '20200101',
             'heure_transaction': '01:01:01'}
         response = backend.response(urllib.urlencode(data))
-        self.assertEqual(response.order_id, order_id)
+        self.assertEqual(response.order_id, reference)
         assert not response.signed
         assert response.transaction_date.isoformat() == '2020-01-01T01:01:01+01:00'
 
